@@ -14,7 +14,6 @@
 #    under the License.
 
 import ctypes
-import errno
 import os
 import six
 import struct
@@ -24,7 +23,6 @@ from eventlet import patcher
 from oslo_log import log as logging
 from oslo_utils import units
 
-from os_win._i18n import _LE
 from os_win import constants
 from os_win import exceptions
 from os_win.utils import win32utils
@@ -110,13 +108,8 @@ class IOThread(native_threading.Thread):
     def run(self):
         try:
             self._copy()
-        except IOError as err:
+        except Exception:
             self._stopped.set()
-            # Invalid argument error means that the vm console pipe was closed,
-            # probably the vm was stopped. The worker can stop it's execution.
-            if err.errno != errno.EINVAL:
-                LOG.error(_LE("Error writing vm console log file from "
-                              "serial console pipe. Error: %s") % err)
 
     def _copy(self):
         with open(self._src, 'rb') as src:
