@@ -26,7 +26,8 @@ from os_win.utils.storage.initiator import iscsi_cli_utils
 hyper_opts = [
     cfg.BoolOpt('force_volumeutils_v1',
                 default=False,
-                help='Force V1 volume utility class'),
+                help='DEPRECATED: Force V1 volume utility class',
+                deprecated_for_removal=True),
 ]
 
 CONF = cfg.CONF
@@ -124,6 +125,17 @@ utils_map = {
             'min_version': 10,
             'max_version': None,
             'path': 'os_win.utils.compute.vmutils10.VMUtils10'}},
+    'clusterutils': {
+        'ClusterUtils': {
+            'min_version': 6.2,
+            'max_version': None,
+            'path': 'os_win.utils.compute.clusterutils.ClusterUtils'}},
+    'cluster_failover_monitor': {
+        'ClusterFailoverMonitor': {
+            'min_version': 6.2,
+            'max_version': None,
+            'path': 'os_win.utils.compute.clusterutils.ClusterFailoverMonitor'
+        }},
 }
 
 
@@ -210,3 +222,11 @@ def get_fc_utils():
 
 def get_diskutils():
     return _get_class(class_type='diskutils')
+
+
+def get_clusterutils():
+    return _get_class(class_type='clusterutils')
+
+
+def get_cluster_failover_monitor():
+    return _get_class(class_type='cluster_failover_monitor')
